@@ -33,9 +33,11 @@
     MapPrototypeHas,
     MapPrototypeGet,
     MapPrototypeSet,
+    ObjectPrototypeIsPrototypeOf,
     RangeError,
     RegExp,
     RegExpPrototypeTest,
+    SafeArrayIterator,
     Symbol,
     SymbolFor,
     TypeError,
@@ -44,7 +46,11 @@
   const VCHAR = ["\x21-\x7E"];
   const OBS_TEXT = ["\x80-\xFF"];
 
-  const REASON_PHRASE = [...HTTP_TAB_OR_SPACE, ...VCHAR, ...OBS_TEXT];
+  const REASON_PHRASE = [
+    ...new SafeArrayIterator(HTTP_TAB_OR_SPACE),
+    ...new SafeArrayIterator(VCHAR),
+    ...new SafeArrayIterator(OBS_TEXT),
+  ];
   const REASON_PHRASE_MATCHER = regexMatcher(REASON_PHRASE);
   const REASON_PHRASE_RE = new RegExp(`^[${REASON_PHRASE_MATCHER}]*$`);
 
@@ -89,9 +95,11 @@
    * @returns {InnerResponse}
    */
   function cloneInnerResponse(response) {
-    const urlList = [...response.urlList];
+    const urlList = [...new SafeArrayIterator(response.urlList)];
     const headerList = [
-      ...ArrayPrototypeMap(response.headerList, (x) => [x[0], x[1]]),
+      ...new SafeArrayIterator(
+        ArrayPrototypeMap(response.headerList, (x) => [x[0], x[1]]),
+      ),
     ];
     let body = null;
     if (response.body !== null) {
@@ -297,7 +305,7 @@
      * @returns {"basic" | "cors" | "default" | "error" | "opaque" | "opaqueredirect"}
      */
     get type() {
-      webidl.assertBranded(this, Response);
+      webidl.assertBranded(this, ResponsePrototype);
       return this[_response].type;
     }
 
@@ -305,7 +313,7 @@
      * @returns {string}
      */
     get url() {
-      webidl.assertBranded(this, Response);
+      webidl.assertBranded(this, ResponsePrototype);
       const url = this[_response].url();
       if (url === null) return "";
       const newUrl = new URL(url);
@@ -317,7 +325,7 @@
      * @returns {boolean}
      */
     get redirected() {
-      webidl.assertBranded(this, Response);
+      webidl.assertBranded(this, ResponsePrototype);
       return this[_response].urlList.length > 1;
     }
 
@@ -325,7 +333,7 @@
      * @returns {number}
      */
     get status() {
-      webidl.assertBranded(this, Response);
+      webidl.assertBranded(this, ResponsePrototype);
       return this[_response].status;
     }
 
@@ -333,7 +341,7 @@
      * @returns {boolean}
      */
     get ok() {
-      webidl.assertBranded(this, Response);
+      webidl.assertBranded(this, ResponsePrototype);
       const status = this[_response].status;
       return status >= 200 && status <= 299;
     }
@@ -342,7 +350,7 @@
      * @returns {string}
      */
     get statusText() {
-      webidl.assertBranded(this, Response);
+      webidl.assertBranded(this, ResponsePrototype);
       return this[_response].statusMessage;
     }
 
@@ -350,7 +358,7 @@
      * @returns {Headers}
      */
     get headers() {
-      webidl.assertBranded(this, Response);
+      webidl.assertBranded(this, ResponsePrototype);
       return this[_headers];
     }
 
@@ -358,7 +366,7 @@
      * @returns {Response}
      */
     clone() {
-      webidl.assertBranded(this, Response);
+      webidl.assertBranded(this, ResponsePrototype);
       if (this[_body] && this[_body].unusable()) {
         throw new TypeError("Body is unusable.");
       }
@@ -375,7 +383,7 @@
     [SymbolFor("Deno.customInspect")](inspect) {
       return inspect(consoleInternal.createFilteredInspectProxy({
         object: this,
-        evaluate: this instanceof Response,
+        evaluate: ObjectPrototypeIsPrototypeOf(ResponsePrototype, this),
         keys: [
           "body",
           "bodyUsed",
@@ -390,13 +398,13 @@
     }
   }
 
-  mixinBody(Response, _body, _mimeType);
-
   webidl.configurePrototype(Response);
+  const ResponsePrototype = Response.prototype;
+  mixinBody(ResponsePrototype, _body, _mimeType);
 
   webidl.converters["Response"] = webidl.createInterfaceConverter(
     "Response",
-    Response,
+    ResponsePrototype,
   );
   webidl.converters["ResponseInit"] = webidl.createDictionaryConverter(
     "ResponseInit",
@@ -457,6 +465,7 @@
 
   window.__bootstrap.fetch ??= {};
   window.__bootstrap.fetch.Response = Response;
+  window.__bootstrap.fetch.ResponsePrototype = ResponsePrototype;
   window.__bootstrap.fetch.newInnerResponse = newInnerResponse;
   window.__bootstrap.fetch.toInnerResponse = toInnerResponse;
   window.__bootstrap.fetch.fromInnerResponse = fromInnerResponse;
